@@ -12,6 +12,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import copy
 import math
 import warnings
 
@@ -23,6 +24,7 @@ from six.moves import urllib
 
 from openstack import version as openstack_version
 from openstack import _log
+from openstack.config import _util
 from openstack.config import defaults as config_defaults
 from openstack import exceptions
 
@@ -78,11 +80,14 @@ class CloudRegion(object):
                  force_ipv4=False, auth_plugin=None,
                  openstack_config=None, session_constructor=None,
                  app_name=None, app_version=None, session=None,
-                 discovery_cache=None):
-
+                 discovery_cache=None, extra_config=None,
+                 cache_expiration_time=0, cache_expirations=None,
+                 cache_path=None, cache_class='dogpile.cache.null',
+                 cache_arguments=None, password_callback=None):
         self._name = name
         self.region_name = region_name
-        self.config = config
+        self.config = _util.normalize_keys(config)
+        self._extra_config = extra_config or {}
         self.log = _log.setup_logging('openstack.config')
         self._force_ipv4 = force_ipv4
         self._auth = auth_plugin
@@ -92,6 +97,12 @@ class CloudRegion(object):
         self._app_name = app_name
         self._app_version = app_version
         self._discovery_cache = discovery_cache or None
+        self._cache_expiration_time = cache_expiration_time
+        self._cache_expirations = cache_expirations or {}
+        self._cache_path = cache_path
+        self._cache_class = cache_class
+        self._cache_arguments = cache_arguments
+        self._password_callback = password_callback
 
     def __getattr__(self, key):
         """Return arbitrary attributes."""
@@ -231,6 +242,23 @@ class CloudRegion(object):
         """Return a keystoneauth plugin from the auth credentials."""
         return self._auth
 
+    def insert_user_agent(self):
+        """Set sdk information into the user agent of the Session.
+
+        .. warning::
+            This method is here to be used by os-client-config. It exists
+            as a hook point so that os-client-config can provice backwards
+            compatibility and still be in the User Agent for people using
+            os-client-config directly.
+
+        Normal consumers of SDK should use app_name and app_version. However,
+        if someone else writes a subclass of
+        :class:`~openstack.config.cloud_region.CloudRegion` it may be
+        desirable.
+        """
+        self._keystone_session.additional_user_agent.append(
+            ('openstacksdk', openstack_version.__version__))
+
     def get_session(self):
         """Return a keystoneauth session based on the auth credentials."""
         if self._keystone_session is None:
@@ -252,9 +280,7 @@ class CloudRegion(object):
                 cert=cert,
                 timeout=self.config['api_timeout'],
                 discovery_cache=self._discovery_cache)
-            if hasattr(self._keystone_session, 'additional_user_agent'):
-                self._keystone_session.additional_user_agent.append(
-                    ('openstacksdk', openstack_version.__version__))
+            self.insert_user_agent()
             # Using old keystoneauth with new os-client-config fails if
             # we pass in app_name and app_version. Those are not essential,
             # nor a reason to bump our minimum, so just test for the session
@@ -269,7 +295,7 @@ class CloudRegion(object):
         """Helper method to grab the service catalog."""
         return self._auth.get_access(self.get_session()).service_catalog
 
-    def _get_version_args(self, service_key, version):
+    def _get_version_request(self, service_key, version):
         """Translate OCC version args to those needed by ksa adapter.
 
         If no version is requested explicitly and we have a configured version,
@@ -281,15 +307,21 @@ class CloudRegion(object):
         If version is not set and we don't have a configured version, default
         to latest.
         """
+        version_request = _util.VersionRequest()
         if version == 'latest':
-            return None, None, 'latest'
+            version_request.max_api_version = 'latest'
+            return version_request
+
         if not version:
             version = self.get_api_version(service_key)
+
         # Octavia doens't have a version discovery document. Hard-code an
         # exception to this logic for now.
         if not version and service_key not in ('load-balancer',):
-            return None, None, 'latest'
-        return version, None, None
+            version_request.max_api_version = 'latest'
+        else:
+            version_request.version = version
+        return version_request
 
     def get_session_client(
             self, service_key, version=None, constructor=adapter.Adapter,
@@ -307,8 +339,7 @@ class CloudRegion(object):
 
         and it will work like you think.
         """
-        (version, min_version, max_version) = self._get_version_args(
-            service_key, version)
+        version_request = self._get_version_request(service_key, version)
 
         return constructor(
             session=self.get_session(),
@@ -316,9 +347,9 @@ class CloudRegion(object):
             service_name=self.get_service_name(service_key),
             interface=self.get_interface(service_key),
             region_name=self.region_name,
-            version=version,
-            min_version=min_version,
-            max_version=max_version,
+            version=version_request.version,
+            min_version=version_request.min_api_version,
+            max_version=version_request.max_api_version,
             **kwargs)
 
     def _get_highest_endpoint(self, service_types, kwargs):
@@ -383,26 +414,20 @@ class CloudRegion(object):
         return endpoint
 
     def get_cache_expiration_time(self):
-        if self._openstack_config:
-            return self._openstack_config.get_cache_expiration_time()
-        return 0
+        # TODO(mordred) We should be validating/transforming this on input
+        return int(self._cache_expiration_time)
 
     def get_cache_path(self):
-        if self._openstack_config:
-            return self._openstack_config.get_cache_path()
+        return self._cache_path
 
     def get_cache_class(self):
-        if self._openstack_config:
-            return self._openstack_config.get_cache_class()
-        return 'dogpile.cache.null'
+        return self._cache_class
 
     def get_cache_arguments(self):
-        if self._openstack_config:
-            return self._openstack_config.get_cache_arguments()
+        return copy.deepcopy(self._cache_arguments)
 
-    def get_cache_expiration(self):
-        if self._openstack_config:
-            return self._openstack_config.get_cache_expiration()
+    def get_cache_expirations(self):
+        return copy.deepcopy(self._cache_expirations)
 
     def get_cache_resource_expiration(self, resource, default=None):
         """Get expiration time for a resource
@@ -413,11 +438,9 @@ class CloudRegion(object):
 
         :returns: Expiration time for the resource type as float or default
         """
-        if self._openstack_config:
-            expiration = self._openstack_config.get_cache_expiration()
-            if resource not in expiration:
-                return default
-            return float(expiration[resource])
+        if resource not in self._cache_expirations:
+            return default
+        return float(self._cache_expirations[resource])
 
     def requires_floating_ip(self):
         """Return whether or not this cloud requires floating ips.
@@ -488,6 +511,20 @@ class CloudRegion(object):
                 return net['name']
         return None
 
+    def _get_extra_config(self, key, defaults=None):
+        """Fetch an arbitrary extra chunk of config, laying in defaults.
+
+        :param string key: name of the config section to fetch
+        :param dict defaults: (optional) default values to merge under the
+                                         found config
+        """
+        defaults = _util.normalize_keys(defaults or {})
+        if not key:
+            return defaults
+        return _util.merge_clouds(
+            defaults,
+            _util.normalize_keys(self._extra_config.get(key, {})))
+
     def get_client_config(self, name=None, defaults=None):
         """Get config settings for a named client.
 
@@ -505,7 +542,8 @@ class CloudRegion(object):
             A dict containing merged settings from the named section, the
             client section and the defaults.
         """
-        if not self._openstack_config:
-            return defaults or {}
-        return self._openstack_config.get_extra_config(
-            name, self._openstack_config.get_extra_config('client', defaults))
+        return self._get_extra_config(
+            name, self._get_extra_config('client', defaults))
+
+    def get_password_callback(self):
+        return self._password_callback
