@@ -22,23 +22,13 @@ class QoSDSCPMarkingRule(resource.Resource):
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
+    allow_get = True
     allow_update = True
     allow_delete = True
     allow_list = True
 
     # Properties
-    #: QoS DSCP marking rule id.
-    id = resource.prop('id')
     #: The ID of the QoS policy who owns rule.
-    qos_policy_id = resource.prop('qos_policy_id')
+    qos_policy_id = resource.URI('qos_policy_id')
     #: DSCP mark field.
-    dscp_mark = resource.prop('dscp_mark')
-
-    @classmethod
-    def _get_create_body(cls, attrs):
-        # Exclude qos_policy_id from attrs since it is not expected by QoS API.
-        if 'qos_policy_id' in attrs:
-            attrs.pop('qos_policy_id')
-
-        return {cls.resource_key: attrs}
+    dscp_mark = resource.Body('dscp_mark')
